==> haskell-storablevector-0.2.13-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-JkMnBBxeCL8Wexi70mmlF
key: storablevector-0.2.13-JkMnBBxeCL8Wexi70mmlF
license: BSD-3-Clause
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
abi: c882debeaee1cd1541520fe7be3ee34f
exposed: True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
import-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-JkMnBBxeCL8Wexi70mmlF
depends:
    QuickCheck-2.13.1-BED53w0KTtOAjBW8qj2Yxi base-4.12.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-KBHPSaZEmqgGszON1MfuOB
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 transformers-0.5.6.2
    unsafe-0.0-t7t4lSr6WV4IGS6VALirJ
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storablevector
version: 0.2.13
id: storablevector-0.2.13-ETAlm5CitoxEFFGaocLhUC
key: storablevector-0.2.13-ETAlm5CitoxEFFGaocLhUC
license: BSD-3-Clause
maintainer: Henning Thielemann <storablevector@henning-thielemann.de>
author: Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>
stability: Experimental
homepage: http://www.haskell.org/haskellwiki/Storable_Vector
synopsis: Fast, packed, strict storable arrays with a list interface like ByteString
description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.
    .
    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.
category: Data
abi: 26fed0bc591cfdc61ef87783c115ae43
exposed: True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict
hidden-modules: Data.StorableVector.Memory
                Data.StorableVector.ST.Private
                Data.StorableVector.Lazy.PointerPrivate
                Data.StorableVector.Lazy.PointerPrivateIndex
                Data.StorableVector.Cursor
import-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
library-dirs: /usr/lib/ghc-8.6.5/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/storablevector-0.2.13
hs-libraries: HSstorablevector-0.2.13-ETAlm5CitoxEFFGaocLhUC
depends:
    QuickCheck-2.13.1-7krqagqcRmA9RWDtUhyOg8 base-4.12.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-AZoiEBEtYZ6EOf9p0UR8go
    syb-0.7.1-1gO4OjQOULM8usUjWwwEyW transformers-0.5.6.2
    unsafe-0.0-t7t4lSr6WV4IGS6VALirJ
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storablevector/html/storablevector.haddock
haddock-html: /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
